%define libname %mklibname %{name}

Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Name:		alsa-plugins
Version:	1.2.2
Release:	%mkrel 2
# All packages are LGPLv2+ with the exception of samplerate which is GPLv2+
License:	GPLv2+ and LGPLv2+
Group:		Sound/Utilities
URL:		http://www.alsa-project.org
Source0:	ftp://ftp.alsa-project.org/pub/plugins/%{name}-%{version}.tar.bz2
Source1:	jack.conf
Source2:	samplerate.conf
Source3:	upmix.conf
Source4:	vdownmix.conf
Source5:	a52.conf

BuildRequires:	kernel-headers >= 2.4.0
BuildRequires:	pkgconfig(alsa) >= %{version}
BuildRequires:	pkgconfig(libpulse) >= 0.8
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(speex)

%description
Advanced Linux Sound Architecture (ALSA) utilities. Modularized architecture
with support for a large range of ISA and PCI cards. Fully compatible with
OSS/Lite (kernel sound drivers), but contains many enhanced features.

This is the plugins package, which allows you to manipulate ALSA settings.

%package -n	%{libname}
Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
Obsoletes:	%{name} < %{version}-%{release}
Requires:	libalsa >= %{version}
Requires:	%{name}-config = %{version}

%description -n	%{libname}
Advanced Linux Sound Architecture (ALSA) utilities. Modularized architecture
with support for a large range of ISA and PCI cards. Fully compatible with
OSS/Lite (kernel sound drivers), but contains many enhanced features.

This is the plugins package, which allows you to manipulate ALSA settings.

%package	doc
Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Group:		Documentation
BuildArch:	noarch

%description	doc
Documentation for %{name}

# (tv) needed for biarch:
%package config
Summary:	Alsa plugins configuration
Group:		System/Configuration
License:	LGPLv2+
BuildArch:	noarch
Conflicts: 	lib64alsa-plugins <= 1.1.1-1.mga6
Conflicts: 	libalsa-plugins <= 1.1.1-1.mga6

%description config
This package contains configuration files for ALSA plugins.

# (tv) needed for biarch:
%package	pulse-config
Summary:	Alsa to PulseAudio backend configuration
Group:		System/Configuration
License:	LGPLv2+
BuildArch:	noarch
# (eatdirt) Otherwise config file alone
Requires:	alsa-plugins-pulseaudio
# (cg) For upgrading from old configuration system
Requires(post):	libalsa-data >= 1.0.20-2
Requires(post):	update-alternatives

%description	pulse-config
This package contains configuration files for the pulse ALSA plugin.

%post pulse-config
# (cg) Check to see if the user has disabled pulse in the old style setup.
if [ -f %{_sysconfdir}/alsa/pulse-default.conf ]; then
  if grep "^#DRAKSOUND- " %{_sysconfdir}/alsa/pulse-default.conf 2>/dev/null >/dev/null; then
    update-alternatives --set soundprofile /etc/sound/profiles/alsa
  fi
fi

%package -n	%{libname}-pulseaudio
Summary:	Alsa to PulseAudio backend
Group:		System/Libraries
License:	LGPLv2+
Provides:	%{name}-pulseaudio = %{version}-%{release}
Requires:	%{name}-pulse-config
Requires:	pulseaudio
%ifarch x86_64
# (cg) Suggest the 32 bit plugin on 64 bits to ensure compatibility
#      with (typically closed source) 32 bit apps.
Recommends:	lib%{name}-pulseaudio
%endif

%description -n	%{libname}-pulseaudio
This plugin allows any program that uses the ALSA API to access a PulseAudio
sound daemon. In other words, native ALSA applications can play and record
sound across a network. There are two plugins in the suite, one for PCM and
one for mixer control.

%package -n	%{libname}-jack
Summary:	Jack PCM output plugin for ALSA
Group:		System/Libraries
License:	LGPLv2+
Provides:	%{name}-jack = %{version}-%{release}

%description -n	%{libname}-jack
This plugin converts the ALSA API over JACK (Jack Audio Connection
Kit, http://jackit.sf.net) API.  ALSA native applications can work
transparently together with jackd for both playback and capture.

    ALSA apps (playback) -> ALSA-lib -> JACK plugin -> JACK daemon
    ALSA apps (capture) <- ALSA-lib <- JACK plugin <- JACK daemon

This plugin provides the PCM type "jack"

%package -n	%{libname}-a52
Summary:	A52/AC3 output plugin for ALSA
Group:		System/Libraries
License:	LGPLv2+
Provides:	%{name}-a52 = %{version}-%{release}
Conflicts:	%{libname} <= 1.0.25-1

%description -n	%{libname}-a52
This plugin supports Digital 5.1 AC3 emulation over S/PDIF (IEC958).

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi
%configure
%make_build

%install
%make_install mkdir_p="mkdir -p"

find %{buildroot} -name '*.la' -delete

install -d %{buildroot}%{_sysconfdir}/alsa

install -d %{buildroot}%{_datadir}/alsa/pcm
install -m 644 %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{buildroot}%{_datadir}/alsa/pcm
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/alsa/alsa.conf.d

# (cg) Include a configuration for when pulse is active
install -d  %{buildroot}%{_sysconfdir}/sound/profiles/pulse

# (cg) Use the "pulseaudio by default" config for the pulse sound profile.
ln -s %{_sysconfdir}/alsa/conf.d/99-pulseaudio-default.conf.example %{buildroot}%{_sysconfdir}/sound/profiles/pulse/alsa-default.conf

%files doc
%doc COPYING* doc/R* doc/*.txt

%files -n %{libname}
%dir %{_libdir}/alsa-lib/
%{_libdir}/alsa-lib/libasound_module_ctl_arcam_av.so
%{_libdir}/alsa-lib/libasound_module_ctl_oss.so
%{_libdir}/alsa-lib/libasound_module_pcm_oss.so
%{_libdir}/alsa-lib/libasound_module_pcm_upmix.so
%{_libdir}/alsa-lib/libasound_module_pcm_usb_stream.so
%{_libdir}/alsa-lib/libasound_module_pcm_vdownmix.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_fast.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_faster.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_high.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_higher.so
%{_libdir}/alsa-lib/libasound_module_rate_samplerate.so
%{_libdir}/alsa-lib/libasound_module_rate_samplerate_best.so
%{_libdir}/alsa-lib/libasound_module_rate_samplerate_linear.so
%{_libdir}/alsa-lib/libasound_module_rate_samplerate_medium.so
%{_libdir}/alsa-lib/libasound_module_rate_samplerate_order.so
%{_libdir}/alsa-lib/libasound_module_rate_speexrate.so
%{_libdir}/alsa-lib/libasound_module_rate_speexrate_best.so
%{_libdir}/alsa-lib/libasound_module_rate_speexrate_medium.so

%files config
%{_datadir}/alsa/pcm/samplerate.conf
%{_datadir}/alsa/pcm/upmix.conf
%{_datadir}/alsa/pcm/vdownmix.conf
%{_datadir}/alsa/alsa.conf.d/10-samplerate.conf
%{_datadir}/alsa/alsa.conf.d/10-rate-lav.conf
%{_datadir}/alsa/alsa.conf.d/10-speexrate.conf
%{_datadir}/alsa/alsa.conf.d/50-arcam-av-ctl.conf
%{_datadir}/alsa/alsa.conf.d/50-oss.conf
%{_datadir}/alsa/alsa.conf.d/60-upmix.conf
%{_datadir}/alsa/alsa.conf.d/60-vdownmix.conf
%{_datadir}/alsa/alsa.conf.d/98-usb-stream.conf
%{_sysconfdir}/alsa/conf.d/10-samplerate.conf
%{_sysconfdir}/alsa/conf.d/10-rate-lav.conf
%{_sysconfdir}/alsa/conf.d/10-speexrate.conf
%{_sysconfdir}/alsa/conf.d/50-arcam-av-ctl.conf
%{_sysconfdir}/alsa/conf.d/50-oss.conf
%{_sysconfdir}/alsa/conf.d/60-upmix.conf
%{_sysconfdir}/alsa/conf.d/60-vdownmix.conf
%{_sysconfdir}/alsa/conf.d/98-usb-stream.conf

%files pulse-config
%{_datadir}/alsa/alsa.conf.d/50-pulseaudio.conf
%{_sysconfdir}/sound/profiles/pulse/alsa-default.conf
%{_sysconfdir}/alsa/conf.d/50-pulseaudio.conf
%{_sysconfdir}/alsa/conf.d/99-pulseaudio-default.conf.example

%files -n %{libname}-pulseaudio
%doc doc/README-pulse
%{_libdir}/alsa-lib/libasound_module_pcm_pulse.so
%{_libdir}/alsa-lib/libasound_module_ctl_pulse.so
%{_libdir}/alsa-lib/libasound_module_conf_pulse.so

%files -n %{libname}-jack
%doc doc/README-jack
%{_datadir}/alsa/pcm/jack.conf
%{_libdir}/alsa-lib/libasound_module_pcm_jack.so
%{_datadir}/alsa/alsa.conf.d/50-jack.conf
%{_sysconfdir}/alsa/conf.d/50-jack.conf

%files -n %{libname}-a52
%{_datadir}/alsa/alsa.conf.d/a52.conf
%{_libdir}/alsa-lib/libasound_module_pcm_a52.so
%{_datadir}/alsa/alsa.conf.d/60-a52-encoder.conf
%{_sysconfdir}/alsa/conf.d/60-a52-encoder.conf


%changelog
* Mon Jul 20 2020 daviddavid <daviddavid> 1.2.2-2.mga8
+ Revision: 1607314
- alsa-plugins-pulseaudio requires pulseaudio (mga#26972)

* Thu Feb 20 2020 luigiwalser <luigiwalser> 1.2.2-1.mga8
+ Revision: 1546095
- 1.2.2

* Tue Feb 18 2020 umeabot <umeabot> 1.2.1-2.mga8
+ Revision: 1542190
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.2.1-1.mga8
+ Revision: 1476081
- 1.2.1

* Sun May 12 2019 luigiwalser <luigiwalser> 1.1.9-1.mga7
+ Revision: 1397339
- 1.1.9

* Thu Jan 10 2019 luigiwalser <luigiwalser> 1.1.8-1.mga7
+ Revision: 1354303
- 1.1.8
- remove upstream patch

* Tue Oct 23 2018 tmb <tmb> 1.1.7-2.mga7
+ Revision: 1324607
- a52_close: set slave to NULL to avoid double pcm free in open fcn

* Wed Oct 17 2018 luigiwalser <luigiwalser> 1.1.7-1.mga7
+ Revision: 1321892
- remove upstream patch
- 1.1.7

* Fri Sep 21 2018 umeabot <umeabot> 1.1.6-4.mga7
+ Revision: 1294294
- Mageia 7 Mass Rebuild

* Thu Jun 21 2018 wally <wally> 1.1.6-3.mga7
+ Revision: 1238558
- explicitly list alsa modules to workaround rpm's dangling symlink bug when exclude is used in files section (mga#22406)

* Thu May 03 2018 daviddavid <daviddavid> 1.1.6-2.mga7
+ Revision: 1225492
- backport some upstream fixes thus fixing ffmpeg 4.0 build
+ tv <tv>
- rebuild with ffmpeg-4

* Sun Apr 08 2018 luigiwalser <luigiwalser> 1.1.6-1.mga7
+ Revision: 1216077
- own plugins dir
- 1.1.6

* Thu Nov 23 2017 luigiwalser <luigiwalser> 1.1.5-1.mga7
+ Revision: 1178999
- 1.1.5

* Tue May 16 2017 luigiwalser <luigiwalser> 1.1.4-1.mga6
+ Revision: 1102144
- 1.1.4

* Tue May 02 2017 akien <akien> 1.1.1-4.mga6
+ Revision: 1098348
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.1.1-3.mga6
+ Revision: 1089833
- Rebuild for ffmpeg 3.2.4

* Sun Jan 29 2017 tv <tv> 1.1.1-2.mga6
+ Revision: 1083925
- split config files thus fixing upgrade of biarch mga5
- rebuild for new libavcodec

* Fri Apr 01 2016 tv <tv> 1.1.1-1.mga6
+ Revision: 997366
- new release

* Sat Feb 13 2016 umeabot <umeabot> 1.1.0-2.mga6
+ Revision: 959485
- Mageia 6 Mass Rebuild
+ tv <tv>
- switch to pkgconfig() BRs

* Mon Nov 09 2015 tv <tv> 1.1.0-1.mga6
+ Revision: 900065
- new release

* Tue Jun 23 2015 tv <tv> 1.0.29-1.mga6
+ Revision: 840245
- new release

* Fri Nov 14 2014 fwang <fwang> 1.0.28-6.mga5
+ Revision: 796997
- rebuild for new ffmpeg

* Wed Oct 15 2014 umeabot <umeabot> 1.0.28-5.mga5
+ Revision: 743289
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.28-4.mga5
+ Revision: 725938
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.28-3.mga5
+ Revision: 686489
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0.28-2.mga5
+ Revision: 677740
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Jun 18 2014 tv <tv> 1.0.28-1.mga5
+ Revision: 637902
- drop merged patches
- new release

* Sat Oct 19 2013 umeabot <umeabot> 1.0.27-3.mga4
+ Revision: 529959
- Mageia 4 Mass Rebuild

* Mon Jul 15 2013 fwang <fwang> 1.0.27-2.mga4
+ Revision: 454502
- correct condition
- check new function
- rebuild for new ffmpeg

* Fri May 24 2013 tv <tv> 1.0.27-1.mga4
+ Revision: 426567
- drop merged patches
- new release

* Wed Jan 23 2013 fwang <fwang> 1.0.26-4.mga3
+ Revision: 391393
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 1.0.26-3.mga3
+ Revision: 345517
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 21 2012 barjac <barjac> 1.0.26-2.mga3
+ Revision: 320104
- Changed group(s) in line with new policy
- spec clean mainly indentation and tabs

* Wed Sep 12 2012 fwang <fwang> 1.0.26-1.mga3
+ Revision: 292479
- new version 1.0.26

* Wed May 30 2012 fwang <fwang> 1.0.25-4.mga3
+ Revision: 250182
- fix build with latest ffmpeg
+ ovitters <ovitters>
- rebuild due to new ffmpeg

* Sun Apr 15 2012 colin <colin> 1.0.25-3.mga2
+ Revision: 230910
- Slightly improved a52 config file.

* Sun Apr 15 2012 colin <colin> 1.0.25-2.mga2
+ Revision: 230887
- Split a52 plugin into subpackage and provide default config.

* Wed Jan 25 2012 colin <colin> 1.0.25-1.mga2
+ Revision: 201523
- New version: 1.0.25

* Mon Nov 28 2011 eatdirt <eatdirt> 1.0.24-5.mga2
+ Revision: 173850
- pulse-config now requires alsa-plugins-pulseaudio (bug #2966)

* Thu Sep 22 2011 fwang <fwang> 1.0.24-4.mga2
+ Revision: 146757
- update missing versioned req
- drop .la files

* Sat Sep 17 2011 colin <colin> 1.0.24-3.mga2
+ Revision: 144508
- Use upstream-submitted patch for pulseaudio config
- Tidy up some sources (pcm-oss was unused)
- Make alsa-plugins-pulse-config noarch
+ ze <ze>
- set documents package as noarch

* Fri Jun 24 2011 fwang <fwang> 1.0.24-2.mga2
+ Revision: 113071
- rebuild for new ffmpeg

* Tue Mar 08 2011 ahmad <ahmad> 1.0.24-1.mga1
+ Revision: 66354
- update to 1.0.24

* Sun Jan 09 2011 ahmad <ahmad> 1.0.23-3.mga1
+ Revision: 3180
- clean spec and drop some old conflicts tags
- imported package alsa-plugins


* Mon Nov 29 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.23-3mdv2011.0
+ Revision: 603174
- rebuild

* Tue Apr 27 2010 Christophe Fergeau <cfergeau@mandriva.com> 1.0.23-2mdv2010.1
+ Revision: 539575
- rebuild so that shared libraries are properly stripped again
- rebuild so that shared libraries are properly stripped again

* Sat Apr 17 2010 Colin Guthrie <cguthrie@mandriva.org> 1.0.23-1mdv2010.1
+ Revision: 535803
- New version: 1.0.23

* Sun Dec 20 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.22-1mdv2010.1
+ Revision: 480505
- New version: 1.0.22
- Use %%make (parallel build worked fine in my tests)
- Remove patches from Anssi now commited upstream

* Fri Nov 27 2009 Anssi Hannula <anssi@mandriva.org> 1.0.21-3mdv2010.1
+ Revision: 470655
- fix 5.1 channel order of a52 plugin (patch, fixes #55955)
- fix message about unspecified channel layout when using a52 plugin
  (patch, see #55955)

* Tue Oct 20 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.21-2mdv2010.0
+ Revision: 458361
- Add suggests on the 32-bit pulseaudio plugin on 64-bit systems for better compatibility OOTB

* Tue Sep 01 2009 Thierry Vignaud <tv@mandriva.org> 1.0.21-1mdv2010.0
+ Revision: 423174
- fix build
- new release

* Sun Aug 16 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.20-5mdv2010.0
+ Revision: 416909
- Support the new soundprofile system for chosing which sound system to use.

* Wed Aug 05 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.20-4mdv2010.0
+ Revision: 410291
- More upstream pulse patches

* Fri Jul 31 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.20-3mdv2010.0
+ Revision: 405159
- pulse: Add pause support (upstream)
- pulse: assert()-dectomy (sent upstream)
- pulse: Fix overzealous assert()-dectomy (me - sent upstream)
- pulse: Remove dmix hijack: invalid assesement - will convert to alternatives in due course
- libtoolize

* Fri Jul 24 2009 Colin Guthrie <cguthrie@mandriva.org> 1.0.20-2mdv2010.0
+ Revision: 399264
- When user opts for pulseaudio by default, assimilate dmix too.

* Mon May 11 2009 Thierry Vignaud <tv@mandriva.org> 1.0.20-1mdv2010.0
+ Revision: 374785
- new release

* Fri Feb 20 2009 Thierry Vignaud <tv@mandriva.org> 1.0.19-1mdv2009.1
+ Revision: 343373
- new release

* Thu Oct 30 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.18-1mdv2009.1
+ Revision: 298680
- Final version: 1.0.18
- Drop upstream applied patchs
- Fix recording via pulse

* Mon Oct 13 2008 Götz Waschk <waschk@mandriva.org> 1.0.18-0.rc3.4mdv2009.1
+ Revision: 293113
- rebuild for new ffmpeg

* Thu Oct 02 2008 Frederic Crozat <fcrozat@mandriva.com> 1.0.18-0.rc3.3mdv2009.0
+ Revision: 290823
- Add conflicts to ease upgrade from 2008.0

  + Colin Guthrie <cguthrie@mandriva.org>
    - Add pulse configuration plugin that had been excluded
    - Replace $RPM_BUILD_ROOT with %%{buildroot}

* Fri Sep 19 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.18-0.rc3.2mdv2009.0
+ Revision: 285839
- Apply patch from Lennart Pottering to fix issues with the mainloop
- Change the ALSA hint description when pulse is set as default to make it clearer in apps which list alsa devices and hints

* Wed Sep 10 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.18-0.rc3.1mdv2009.0
+ Revision: 283541
- New release candidate: 1.0.18rc3
- Drop pulse rework patch (merged upstream)

* Wed Sep 03 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.18-0.rc2.2mdv2009.0
+ Revision: 279959
- Apply upstream patch to rework the pulse plugin

* Sun Aug 24 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.18-0.rc2.1mdv2009.0
+ Revision: 275469
- Adapt version requirements for alsa-lib
- Drop upstream applied patches
- New release candidate: 1.0.18 rc2

* Wed Jul 23 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.17-2mdv2009.0
+ Revision: 242058
- Some upstream pulseaudio fixes.

* Wed Jul 16 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.17-1mdv2009.0
+ Revision: 236499
- New version: 1.0.17

* Wed Jun 25 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.17-0.rc2.3mdv2009.0
+ Revision: 229120
- Disable the swparams patch for now pending further investigation. It breaks everything.

* Sun Jun 22 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.17-0.rc2.2mdv2009.0
+ Revision: 227957
- Rename patch from upstream bugtracker for better tracking
- Add additional patch for pulse sw params (wine related)

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 1.0.17-0.rc2.1mdv2009.0
+ Revision: 219568
- remove patches already applied
- new release

* Tue Jun 10 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-9mdv2009.0
+ Revision: 217460
- fix URL

* Wed Apr 02 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-8mdv2008.1
+ Revision: 191635
- remove bogus provides in pulse-config

* Tue Apr 01 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-7mdv2008.1
+ Revision: 191500
- fix upgrading _both_ lib{,64}alsa-plugins-pulse on biarch systems by spliting
  out the config files in a common subpackage (#39414)

* Thu Mar 13 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.16-6mdv2008.1
+ Revision: 187710
- Rebuild
- Add description hint for PulseAudio when default (i.e. aplay -L)

* Wed Mar 12 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-4mdv2008.1
+ Revision: 187096
- patches 2 & 3: official patches from upstream repository to fix pulse asserts
  resulting in unexpected crashes
- patch 1: remove bits already in official patches from unofficial patch

* Mon Mar 10 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.16-3mdv2008.1
+ Revision: 183546
- Allow setting of hints for the pulseaudio plugin (alsa#3834)

* Thu Feb 21 2008 Colin Guthrie <cguthrie@mandriva.org> 1.0.16-2mdv2008.1
+ Revision: 173672
- Apply patch from Alsa bug #2601 to fix an assert in and a buffer calculation in pulseaudio plugin.

* Wed Feb 06 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-1mdv2008.1
+ Revision: 163082
- new release

* Wed Jan 23 2008 Frederic Crozat <fcrozat@mandriva.com> 1.0.16-0.rc1.2mdv2008.1
+ Revision: 157006
- Remove invalid requires (Mdv bug #37098)

* Mon Jan 21 2008 Thierry Vignaud <tv@mandriva.org> 1.0.16-0.rc1.1mdv2008.1
+ Revision: 155929
- new release

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 1.0.15-5mdv2008.1
+ Revision: 152815
- remove useless kernel require

* Fri Dec 28 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.15-4mdv2008.1
+ Revision: 138878
- Patch1 (HG): fix assert in pulse plugin (Alsa bug #3470)
- Patch2 (HG): add minmax condition for pulse plugin (Alsa bug #2601)
- Patch3 (HG): report XRUN state back to application (Fedora)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Dec 12 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.15-3mdv2008.1
+ Revision: 118015
- Use correct path for alsa config files, it isn't the same as Fedora

* Wed Dec 05 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.15-2mdv2008.1
+ Revision: 115679
- Move pulseaudio and jack plugin in subpackages
- Add default configuration files for jack, pulseaudio and other plugins (Fedora)

* Tue Oct 16 2007 Thierry Vignaud <tv@mandriva.org> 1.0.15-1mdv2008.1
+ Revision: 99092
- new release

* Sun Oct 14 2007 Colin Guthrie <cguthrie@mandriva.org> 1.0.15-0.rc1.3mdv2008.1
+ Revision: 98172
- Remove erroneous Provides due to over-zealous copy+paste

* Sun Oct 14 2007 Colin Guthrie <cguthrie@mandriva.org> 1.0.15-0.rc1.2mdv2008.1
+ Revision: 98126
- Libify to allow both 32 and 64 bit installation to co-exist

* Tue Oct 09 2007 Thierry Vignaud <tv@mandriva.org> 1.0.15-0.rc1.1mdv2008.1
+ Revision: 95784
- new release

* Tue Sep 25 2007 Colin Guthrie <cguthrie@mandriva.org> 1.0.14-7mdv2008.0
+ Revision: 92913
- Apply upstream/fedora patch for pulse audio defaults.

* Tue Jun 26 2007 Thierry Vignaud <tv@mandriva.org> 1.0.14-6mdv2008.0
+ Revision: 44573
- add buildrequires for more plugins

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 1.0.14-4mdv2008.0
+ Revision: 36245
- rebuild with correct optflags

  + Thierry Vignaud <tv@mandriva.org>
    - new release

* Thu May 03 2007 Thierry Vignaud <tv@mandriva.org> 1.0.14-0.rc4.1mdv2008.0
+ Revision: 21559
- new release


* Thu Mar 08 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.14-0.rc3.1mdv2007.1
+ Revision: 138549
- new release

* Tue Jan 23 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.14-0.rc2.1mdv2007.1
+ Revision: 112299
- new release

* Tue Oct 24 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.0.13-1mdv2007.0
+ Revision: 71861
- new release

* Fri Aug 25 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.0.12-1mdv2007.0
+ Revision: 57846
- new release
- new release
- kill alsaconf rests
- there's no translation catalog
- new release
- fix buildrequires for s/Polypaudio/PulseAudio/ name change

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - import alsa-plugins-1.0.11-3mdk

* Tue May 16 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.0.11-3mdk
- fix buildrequires for x86_64 (#22430)
- remove manual requires already guessed by spec-helper

* Mon May 15 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.0.11-2mdk
- Fix Requires

* Thu May 04 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.0.11-1mdk
- new release
- fix buildrequires
- do not include all sources in doc when locale is not C...

* Wed Nov 16 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.0.10-1mdk
- new release

* Fri Nov 04 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.0.10-0.rc1.1mdk
- new release

* Fri Oct 07 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.0.9-2mdk
- Fix BuildRequires
- %%{1}mdk

* Sat May 28 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.0.9-1mdk
- new release

* Tue May 24 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.0.9-0.rc4.1mdk
- new release

* Tue May 10 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.0.9-0.rc3.1mdk
- new release

* Sat Apr 16 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.0.9-0.rc2.1mdk
- initial release

